@@ -6,8 +6,10 @@
 ;; Homepage: https://github.com/emacscollective/no-littering
 ;; Keywords: convenience
 
-;; Package-Version: 1.7.8
-;; Package-Requires: ((emacs "26.1") (compat "30.1"))
+;; Package-Version: 1.8.1
+;; Package-Requires: (
+;;     (emacs  "26.1")
+;;     (compat "30.1"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -134,6 +136,8 @@ This variable has to be set before `no-littering' is loaded.")
     (setq erc-log-channels-directory       (var "erc/log-channels/"))
     (setq erc-startup-file-list            (list (etc "erc/startup.el") (etc "erc/startup") ".ercrc.el" ".ercrc"))
     (setq eshell-aliases-file              (etc "eshell/aliases"))
+    ;; This controls where `eshell-history-file-name' is places.
+    ;; Other files belong in "etc/" so theme their variables directly.
     (setq eshell-directory-name            (var "eshell/"))
     (setq eshell-login-script              (etc "eshell/login"))
     (setq eshell-rc-script                 (etc "eshell/rc"))
@@ -188,7 +192,8 @@ This variable has to be set before `no-littering' is loaded.")
 
     (eval-after-load 'desktop     '(make-directory desktop-dirname t))
     (eval-after-load 'erc         '(make-directory erc-dcc-get-default-directory t))
-    (eval-after-load 'eshell      '(make-directory eshell-directory-name t))
+    (eval-after-load 'eshell      `(with-file-modes #o700
+                                     (make-directory ,(etc "eshell/") t)))
     (eval-after-load 'eww         '(make-directory eww-bookmarks-directory t))
     (eval-after-load 'gnus        `(make-directory ,(etc "gnus/") t))
     (eval-after-load 'gnus        '(make-directory gnus-dribble-directory t))
@@ -204,6 +209,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq anaconda-mode-installation-directory (var "anaconda-mode/"))
     (setq annotate-file                    (var "annotations.el"))
     (setq async-byte-compile-log-file      (var "async-bytecomp.log"))
+    (setq autocrypt-save-file              (var "autocrypt-data.eld"))
     (setq auto-package-update-last-update-day-path (var "auto-package-update-last-update-day"))
     (setq bbdb-file                        (var "bbdb/bbdb.el"))
     (setq bbdb-vcard-directory             (var "bbdb/vcard/"))
@@ -316,6 +322,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq org-roam-db-location             (var "org/org-roam.db"))
     (setq package-quickstart-file          (var "package-quickstart.el"))
     (setq pandoc-data-dir                  (etc "pandoc-mode/"))
+    (setq parinfer-rust-library-directory  (var "parinfer-rust/"))
     (setq pcache-directory                 (var "pcache/"))
     (setq pdf-view-restore-filename        (var "pdf-view-restore.el"))
     (setq persist--directory-location      (var "persist/"))
@@ -458,15 +465,17 @@ you must turn of these features completely."
           ("\\`/dev/shm\\([^/]*/\\)*\\(.*\\)\\'" "\\2")
           (".*" ,(no-littering-expand-var-file-name "auto-save/") t)))
   (setq backup-directory-alist
-        `((,(concat "\\`" (file-name-as-directory temporary-file-directory)))
-          ("\\`/tmp/" . nil)
-          ("\\`/dev/shm/" . nil)
-          ("." . ,(no-littering-expand-var-file-name "backup/"))))
+        (delete-dups
+         `((,(concat "\\`" (file-name-as-directory temporary-file-directory)))
+           ("\\`/tmp/" . nil)
+           ("\\`/dev/shm/" . nil)
+           ("." . ,(no-littering-expand-var-file-name "backup/")))))
   (setq undo-tree-history-directory-alist
-        `((,(concat "\\`" (file-name-as-directory temporary-file-directory)))
-          ("\\`/tmp/" . nil)
-          ("\\`/dev/shm/" . nil)
-          ("." . ,(no-littering-expand-var-file-name "undo-tree-hist/"))))
+        (delete-dups
+         `((,(concat "\\`" (file-name-as-directory temporary-file-directory)))
+           ("\\`/tmp/" . nil)
+           ("\\`/dev/shm/" . nil)
+           ("." . ,(no-littering-expand-var-file-name "undo-tree-hist/")))))
   )
 
 ;;; _
